/**
 * Determines the type of syntax for a TSDocTagDefinition
 */
export declare enum TSDocTagSyntaxKind {
    /**
     * The tag is intended to be an inline tag.  For example: `{@link}`.
     */
    InlineTag = 0,
    /**
     * The tag is intended to be a block tag that starts a new documentation
     * section.  For example: `@remarks`
     */
    BlockTag = 1,
    /**
     * The tag is intended to be a modifier tag whose presences indicates
     * an aspect of the associated API item.  For example: `@internal`
     */
    ModifierTag = 2
}
/**
 * Constructor parameters for {@link TSDocTagDefinition}
 */
interface ITSDocTagDefinitionParameters {
    tagName: string;
    syntaxKind: TSDocTagSyntaxKind;
    singleton?: boolean;
}
/**
 * Defines a TSDoc tag that will be understood by the TSDocParser.
 */
export declare class TSDocTagDefinition {
    /**
     * The TSDoc tag name.  TSDoc tag names start with an at-sign ("@") followed
     * by ASCII letters using "camelCase" capitalization.
     */
    readonly tagName: string;
    /**
     * The TSDoc tag name in all capitals, which is used for performing
     * case-insensitive comparisons or lookups.
     */
    readonly tagNameWithUpperCase: string;
    /**
     * Specifies the expected syntax for this tag.
     */
    readonly syntaxKind: TSDocTagSyntaxKind;
    /**
     * If true, then at most one instance of this TSDoc tag may appear in a doc comment.
     */
    readonly singleton: boolean;
    constructor(parameters: ITSDocTagDefinitionParameters);
}
/**
 * Configuration for the TSDocParser.
 */
export declare class TSDocParserConfiguration {
    private _tagDefinitions;
    private _tagDefinitionsByName;
    constructor();
    /**
     * The TSDoc block tag names that will be interpreted as modifier tags.
     */
    readonly tagDefinitions: ReadonlyArray<TSDocTagDefinition>;
    /**
     * Return the tag that was defined with the specified name, or undefined
     * if not found.
     */
    tryGetTagDefinition(tagName: string): TSDocTagDefinition | undefined;
    /**
     * Return the tag that was defined with the specified name, or undefined
     * if not found.
     */
    tryGetTagDefinitionWithUpperCase(alreadyUpperCaseTagName: string): TSDocTagDefinition | undefined;
    /**
     * Define a new TSDoc tag to be recognized by the TSDocParser.
     */
    addTagDefinition(tagDefinition: TSDocTagDefinition): void;
    addTagDefinitions(tagDefinitions: ReadonlyArray<TSDocTagDefinition>): void;
}
export {};
